# coding: utf-8

"""
    FlexPrice API

    FlexPrice API Service

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class DtoInvoiceLineItemResponse(BaseModel):
    """
    DtoInvoiceLineItemResponse
    """ # noqa: E501
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    created_at: Optional[StrictStr] = None
    created_by: Optional[StrictStr] = None
    currency: Optional[StrictStr] = None
    customer_id: Optional[StrictStr] = None
    display_name: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    invoice_id: Optional[StrictStr] = None
    metadata: Optional[Dict[str, StrictStr]] = None
    meter_display_name: Optional[StrictStr] = None
    meter_id: Optional[StrictStr] = None
    period_end: Optional[StrictStr] = None
    period_start: Optional[StrictStr] = None
    plan_display_name: Optional[StrictStr] = None
    plan_id: Optional[StrictStr] = None
    price_id: Optional[StrictStr] = None
    price_type: Optional[StrictStr] = None
    quantity: Optional[Union[StrictFloat, StrictInt]] = None
    status: Optional[StrictStr] = None
    subscription_id: Optional[StrictStr] = None
    tenant_id: Optional[StrictStr] = None
    updated_at: Optional[StrictStr] = None
    updated_by: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["amount", "created_at", "created_by", "currency", "customer_id", "display_name", "id", "invoice_id", "metadata", "meter_display_name", "meter_id", "period_end", "period_start", "plan_display_name", "plan_id", "price_id", "price_type", "quantity", "status", "subscription_id", "tenant_id", "updated_at", "updated_by"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DtoInvoiceLineItemResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DtoInvoiceLineItemResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "amount": obj.get("amount"),
            "created_at": obj.get("created_at"),
            "created_by": obj.get("created_by"),
            "currency": obj.get("currency"),
            "customer_id": obj.get("customer_id"),
            "display_name": obj.get("display_name"),
            "id": obj.get("id"),
            "invoice_id": obj.get("invoice_id"),
            "metadata": obj.get("metadata"),
            "meter_display_name": obj.get("meter_display_name"),
            "meter_id": obj.get("meter_id"),
            "period_end": obj.get("period_end"),
            "period_start": obj.get("period_start"),
            "plan_display_name": obj.get("plan_display_name"),
            "plan_id": obj.get("plan_id"),
            "price_id": obj.get("price_id"),
            "price_type": obj.get("price_type"),
            "quantity": obj.get("quantity"),
            "status": obj.get("status"),
            "subscription_id": obj.get("subscription_id"),
            "tenant_id": obj.get("tenant_id"),
            "updated_at": obj.get("updated_at"),
            "updated_by": obj.get("updated_by")
        })
        return _obj


